@@ -3,7 +3,7 @@
 osm <- function(country, var, path, proxy=FALSE, ...) {
 	stopifnot(var %in% c("places", "highways", "railway"))
 	iso <- .getCountryISO(country)
-	path <- .get_path(path)
+	path <- .get_path(path, "osm")
 
 	filename <- paste0(iso, "_", var, ".gpkg")
 	filepath <- file.path(path, filename)
