@@ -1,7 +1,7 @@
 
 
 population <- function(year, res="5", path, ...) {
-	path <- .get_path(path)
+	path <- .get_path(path, "population")
 	stopifnot(as.numeric(year) %in% c(2000, 2005, 2010, 2015, 2020))
 	stopifnot(as.numeric(res) %in% c(10, 5, 2.5, 0.5))
 	res <- ifelse(res==0.5, "30s", paste0(res, "m"))
