@@ -1,12 +1,33 @@
 
+.wcts_month <- function(var, path, time, ...) {
 
-.wccruts <- function(lon, lat, path, ...) {
+	stopifnot(res %in% c("2.5", "5", "10"))
+	stopifnot(var %in% c("tmin", "tmax", "prec"))
+
+	start <- seq(1950, 2010, 10)
+	end <- start + 9
+	end[length(end)] <- 2024
+	tm <- apply(cbind(start, end), 1, function(x) paste(x, collapse="-"))
+	if (!time %in% tm) {
+		stop(paste("time should be one of:", paste(tm, collapse=", ")))
+	}
+
+	path <- .get_path(path, "climate/hist")
+	fname <- paste0("wc2.1_cruts4.09_", res, "_", var, "_", time, ".zip")
+	turl <- .wc_url(paste0("hist/cts4.09/", fname))
+	outfname <- file.path(path, fname)
+	pat <- paste0("wc2.1_cruts4.09_", res, "_", var, "_", substr(time, 1, 3), ".*.tif$")
+	ff <- list.files(path=path, pattern=pat, full.names=TRUE)
+	if (length(ff) == 0) {
+		if (!.downloadDirect(turl, outfname, unzip=TRUE, ...)) return(NULL)
+		ff <- list.files(path=path, pattern=pat, full.names=TRUE)
+	}
+	rast(sort(ff))
 }
 
 
-.get_id <- function(lon, lat) {
-	r <- rast(res=5)	
-	id <- unique(cellFromXY(r, cbind(lon,lat)))
+.did_lonlat <- function(lon, lat) {
+	id <- unique(cellFromXY(rast(res=5), cbind(lon,lat)))
 	if (any(is.na(id))) stop("invalid coordinates (lon/lat reversed?)")
 	path <- system.file(package="geodata")
 	tiles <- readRDS(file.path(path, "ex/tiles.rds"))
@@ -16,43 +37,58 @@
 	id
 }
 
-.wcerad <- function(lon, lat, path, ...) {
+.did_extent <- function(e) {
+	ids <- cells(rast(res=5), e)
+	if (length(ids) == 0) {
+		stop("area is not on earth?")		
+	}
+	path <- system.file(package="geodata")
+	tiles <- readRDS(file.path(path, "ex/tiles.rds"))
+	ids <- ids[ids %in% tiles]
+	if (length(ids) == 0) {
+		stop("there is no weather data for this location (not on land?)")
+	}
+	ids
+}
+
+
+.worldclim_day <- function(x, path, sds=FALSE, ...) {
+
 	path <- .get_path(path, "climate")
-	ids <- .get_id(lon, lat)	
-	#ids <- unique(cellFromXY(r, cbind(lon,lat)))
-	pth <- file.path(path, "wcdera")
-	for (id in ids) {
-		fname <- paste0("wcdera_", id, ".nc")
-		outfname <- file.path(pth, fname)
-		if (!file.exists(outfname)) {
-			dir.create(pth, showWarnings=FALSE)
-			turl <- .wc_url(paste0("day/nc/", fname))
-			if (is.null(turl)) return(NULL)
-			if (!.downloadDirect(turl, outfname, ...)) return(NULL)
+	if (NCOL(x) == 2) {
+		ids <- unique(.did_lonlat(x[,1], x[,2]))
+	} else {
+		ids <- unique(.did_extent(ext(x)))
+	}
+	pth <- file.path(path, "day24")
+	dir.create(pth, showWarnings=FALSE)
+	fname <- paste0("wcd_", ids, ".nc")
+	outfname <- file.path(pth, gsub("_", "24_", fname))
+	for (i in 1:length(fname)) {
+		if (!file.exists(outfname[i])) {
+			turl <- .wc_url(paste0("day/2024/", fname[i]))
+			if (!.downloadDirect(turl, outfname[i], ...)) return(NULL)
 		}
 	}
-	sds(outfname)
-}
-
-
-.wcerad21 <- function(lon, lat, path, ...) {
-	path <- .get_path(path, "climate")
-	id <- .get_id(lon, lat)
-
-	pth <- file.path(path, "wcdera")
-	fname <- paste0("wcdera_", id, ".nc")
-	outfname <- file.path(pth, gsub("_", "21_", fname))
-	if (!file.exists(outfname)) {
-		dir.create(pth, showWarnings=FALSE)
-		turl <- .wc_url(paste0("day/nc21/", fname))
-		if (is.null(turl)) return(NULL)
-		
-		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
+	if (sds && (length(outfname) == 1)) {
+		sds(outfname)
+	} else {
+		outfname
 	}
-	sds(outfname)
 }
 
 
+.good.file.exists <- function(x, raster=TRUE) {
+	if (file.exists(x)) {
+		if (isTRUE(file.info(x)$size > 0)) {
+			return(TRUE)
+		} else {
+			file.remove(x)
+		}
+	}
+	FALSE
+}
+
 
 worldclim_tile <- function(var, lon, lat, path, version="2.1", ...) {
 	stopifnot(var %in% c("tavg", "tmin", "tmax", "prec", "bio", "bioc", "elev", "wind", "vapr", "srad"))
@@ -61,17 +97,17 @@ worldclim_tile <- function(var, lon, lat, path, version="2.1", ...) {
 	if (var == "bioc") var <- "bio"
 	path <- .get_path(path, "climate")
 
-	r <- rast(res=30)
-	id <- cellFromXY(r, cbind(lon,lat))
+	r <- terra::rast(res=30)
+	id <- terra::cellFromXY(r, cbind(lon,lat))
 	if (is.na(id)) stop("invalid coordinates (lon/lat reversed?)")
 
-	pth <- file.path(path, "wc2.1_tiles")
+	pth <- file.path(path, "tiles_2.1")
 	dir.create(pth, showWarnings=FALSE)
 
-	fname <- paste0("tile_", id, "_wc2.1_30s_", var, ".tif")
+	fname <- paste0("tile_", id, "_wc2.1_30s_",	var, ".tif")
 	outfname <- file.path(pth, fname)
 
-	if (!file.exists(outfname)) {
+	if (!.good.file.exists(outfname)) {
 		turl <- .wc_url(paste0("tiles/tile/", fname))
 		if (is.null(turl)) return(NULL)
 	
@@ -87,7 +123,7 @@ worldclim_country <- function(country, var, path, version="2.1", ...) {
 	version <- as.character(version)
 	stopifnot(version %in% c("2.1"))
 	if (var == "bioc") var <- "bio"
-	iso <- .getCountryISO(country)
+	iso <- unique(.getCountryISO(country))
 
 	path <- .get_path(path, "climate")
 	pth <- file.path(path, "wc2.1_country")
@@ -96,12 +132,18 @@ worldclim_country <- function(country, var, path, version="2.1", ...) {
 	fname <- paste0(iso, "_wc2.1_30s_", var, ".tif")
 	outfname <- file.path(pth, fname)
 	
-	if (!file.exists(outfname)) {
-		turl <- .wc_url(paste0("tiles/iso/", fname))
-		if (is.null(turl)) return(NULL)
-		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
+	for (i in 1:length(fname)) {
+		if (!file.exists(outfname[i])) {
+			turl <- .wc_url(paste0("tiles/iso/", fname[i]))
+			if (is.null(turl)) return(NULL)
+			if (!.downloadDirect(turl, outfname[i], ...)) return(NULL)
+		}
+	}
+	if (length(outfname) == 1) {
+		rast(outfname)
+	} else {
+		sprc(outfname)
 	}
-	rast(outfname)
 }
 
 
